==> recursion2loop-0.2.1.tar.gz: recursion2loop-0.2.1/README.md <==
# recursion2iteration

[![PyPI version](https://badge.fury.io/py/recursion2iteration.svg)](https://badge.fury.io/py/recursion2iteration)
[![Python Versions](https://img.shields.io/pypi/pyversions/recursion2iteration.svg)](https://pypi.org/project/recursion2loop/)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

This package provides common recursive patterns to iterative implementations. The goal is to provide stack-safe and memory-efficient iterative implementations in python language.

## Features

- 🔄 Convert recursive functions to iterative implementations
- 🔧 Type-safe implementations with full typing support

## Installation

```bash
pip install recursion2loop
```

## Available Transformations

- Tree Traversals (check for more details: [tree traversal documentation](https://github.com/adilkoken/recursion2loop/blob/main/documentation/doc_tree_traversal.md))
- Tree Operations (check for more details: [tree operations documentation](https://github.com/adilkoken/recursion2loop/blob/main/documentation/doc_tree_operations.md))

# License

This project is licensed under the MIT License - see the [LICENSE](https://github.com/adilkoken/recursion2loop/blob/main/LICENSE) file for details.

# Code of Conduct

This project and everyone participating in it is governed by the [Code of Conduct](https://github.com/adilkoken/recursion2loop/blob/main/CODE_OF_CONDUCT.md). By participating, you are expected to uphold this code.

# Contributing

Your contributions are always welcome! Please take a look at the [contribution guidelines](https://github.com/adilkoken/recursion2loop/blob/main/CONTRIBUTING.md).

==> recursion2loop-0.2.2.tar.gz: recursion2loop-0.2.2/README.md <==
# recursion2iteration

[![PyPI version](https://badge.fury.io/py/recursion2loop.svg)](https://badge.fury.io/py/recursion2loop)
[![Python Versions](https://img.shields.io/pypi/pyversions/recursion2loop.svg)](https://pypi.org/project/recursion2loop/)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

This package provides common recursive patterns to iterative implementations. The goal is to provide stack-safe and memory-efficient iterative implementations in python language.

## Features

- 🔄 Convert recursive functions to iterative implementations
- 🔧 Type-safe implementations with full typing support

## Installation

```bash
pip install recursion2loop
```

## Available Transformations

- Tree Traversals (check for more details: [tree traversal documentation](https://github.com/adilkoken/recursion2loop/blob/main/documentation/doc_tree_traversal.md))
- Tree Operations (check for more details: [tree operations documentation](https://github.com/adilkoken/recursion2loop/blob/main/documentation/doc_tree_operations.md))

# License

This project is licensed under the MIT License - see the [LICENSE](https://github.com/adilkoken/recursion2loop/blob/main/LICENSE) file for details.

# Code of Conduct

This project and everyone participating in it is governed by the [Code of Conduct](https://github.com/adilkoken/recursion2loop/blob/main/CODE_OF_CONDUCT.md). By participating, you are expected to uphold this code.

# Contributing

Your contributions are always welcome! Please take a look at the [contribution guidelines](https://github.com/adilkoken/recursion2loop/blob/main/CONTRIBUTING.md).
